@@ -1,6 +1,6 @@
-""" Contains implementation for raw event info
-"""
-import numpy as np 
+"""Contains implementation for raw event info"""
+
+import numpy as np
 
 from meggie.mainwindow.dynamic import InfoAction
 from meggie.utilities.events import find_stim_channel
@@ -8,10 +8,9 @@ from meggie.utilities.events import find_events
 
 
 class Info(InfoAction):
-    """ Shows event information on a info box.
-    """
+    """Shows event information on a info box."""
 
-    def run(self):
+    def run(self, params={}):
         try:
             subject = self.experiment.active_subject
             if not subject:
@@ -27,16 +26,15 @@ class Info(InfoAction):
             if events is None:
                 return ""
 
-            bins = np.bincount(events[:,2])
+            bins = np.bincount(events[:, 2])
             event_counts = dict()
             for event_id in set(events[:, 2]):
                 event_counts[event_id] = bins[event_id]
 
             events_string = ""
             for key, value in event_counts.items():
-                events_string += 'Trigger %s, %s events\n' % (str(key), str(value))
+                events_string += "Trigger %s, %s events\n" % (str(key), str(value))
 
             return events_string
-        except Exception as exc:
+        except Exception:
             return ""
-
