@@ -1,7 +1,4 @@
-""" Contains controlling logic for tfr create
-"""
-
-import mne
+"""Contains controlling logic for tfr create"""
 
 from meggie.utilities.threading import threaded
 from meggie.utilities.validators import assert_arrays_same
@@ -10,10 +7,10 @@ from meggie.datatypes.tfr.tfr import TFR
 
 
 @threaded
-def create_tfr(subject, tfr_name, epochs_names,
-               freqs, decim, n_cycles, subtract_evoked):
-    """ Handles tfr item creation.
-    """
+def create_tfr(
+    subject, tfr_name, epochs_names, freqs, decim, n_cycles, subtract_evoked
+):
+    """Handles tfr item creation."""
 
     time_arrays = []
     for name in epochs_names:
@@ -28,27 +25,28 @@ def create_tfr(subject, tfr_name, epochs_names,
         if subtract_evoked:
             epochs = epochs.copy().subtract_evoked()
 
-        tfr = mne.time_frequency.tfr.tfr_morlet(epochs, 
-                                                freqs=freqs, 
-                                                n_cycles=n_cycles,
-                                                decim=decim, 
-                                                average=True,
-                                                return_itc=False)
+        tfr = epochs.compute_tfr(
+            "morlet",
+            freqs,
+            n_cycles=n_cycles,
+            decim=decim,
+            average=True,
+            return_itc=False,
+        )
         tfrs[epoch_name] = tfr
 
     # convert list-like to list
-    if hasattr(n_cycles, '__len__'):
+    if hasattr(n_cycles, "__len__"):
         n_cycles = list(n_cycles)
 
     params = {
-        'decim': decim,
-        'n_cycles': n_cycles,
-        'evoked_subtracted': subtract_evoked,
-        'conditions': epochs_names
+        "decim": decim,
+        "n_cycles": n_cycles,
+        "evoked_subtracted": subtract_evoked,
+        "conditions": epochs_names,
     }
 
     meggie_tfr = TFR(tfr_name, subject.tfr_directory, params, tfrs)
 
     meggie_tfr.save_content()
     subject.add(meggie_tfr, "tfr")
-
