@@ -1,6 +1,4 @@
-""" Contains a class for logic of the output options dialog.
-"""
-import logging
+"""Contains a class for logic of the output options dialog."""
 
 from PyQt5 import QtWidgets
 
@@ -8,25 +6,23 @@ from meggie.utilities.dialogs.outputOptionsUi import Ui_outputOptions
 
 
 class OutputOptions(QtWidgets.QDialog):
-    """ Contains logic for the output options dialog.
-    """
+    """Contains logic for the output options dialog."""
 
-    def __init__(self, parent, handler=None,
-                 selected_option=None):
+    def __init__(self, parent, handler=None, selected_option=None):
         QtWidgets.QDialog.__init__(self, parent)
         self.ui = Ui_outputOptions()
         self.ui.setupUi(self)
         self.parent = parent
         self.handler = handler
 
-        if selected_option == 'channel_averages':
+        if selected_option == "channel_averages":
             self.ui.radioButtonChannelAverages.setChecked(True)
 
     def accept(self):
         if self.ui.radioButtonChannelAverages.isChecked():
-            selected_option = 'channel_averages'
+            selected_option = "channel_averages"
         else:
-            selected_option = 'all_channels'
+            selected_option = "all_channels"
 
         if self.handler:
             self.handler(selected_option=selected_option)
