@@ -1,5 +1,4 @@
-"""Functions for plotting purposes.
-"""
+"""Functions for plotting purposes."""
 
 import itertools
 
@@ -17,16 +16,16 @@ def color_cycle(n):
 
     Returns
     -------
-    list 
+    list
         The colors.
 
     """
-    cycler = itertools.cycle(['b', 'r', 'g', 'y', 'm', 'c', 'k', 'pink'])
+    cycler = itertools.cycle(["b", "r", "g", "y", "m", "c", "k", "pink"])
     return list(itertools.islice(cycler, n))
 
 
 def create_channel_average_plot(n_plots, plot_fun, title, legend=None):
-    """Creates a figure with proper subplot layout for channel averages, 
+    """Creates a figure with proper subplot layout for channel averages,
     and calls plot_fun to fill each of the axes.
 
     Parameters
@@ -48,14 +47,15 @@ def create_channel_average_plot(n_plots, plot_fun, title, legend=None):
     ncols = min(4, n_plots)
     nrows = int((n_plots - 1) / ncols + 1)
 
-    fig, axes = plt.subplots(nrows=nrows, ncols=ncols, squeeze=False,
-                             constrained_layout=True)
-    fig.set_size_inches(15, int(10*(nrows/ncols)))
+    fig, axes = plt.subplots(
+        nrows=nrows, ncols=ncols, squeeze=False, constrained_layout=True
+    )
+    fig.set_size_inches(15, int(10 * (nrows / ncols)))
 
-    for ax_idx in range(ncols*nrows):
+    for ax_idx in range(ncols * nrows):
         ax = axes[ax_idx // ncols, ax_idx % ncols]
         if ax_idx >= n_plots:
-            ax.axis('off')
+            ax.axis("off")
             continue
         plot_fun(ax_idx, ax)
 
@@ -68,19 +68,16 @@ def create_channel_average_plot(n_plots, plot_fun, title, legend=None):
         fig.legend(lines, texts)
 
     fig.suptitle(title)
-    set_figure_title(fig, title.replace(' ', '_'))
+    set_figure_title(fig, title.replace(" ", "_"))
 
     return fig
 
 
 def set_figure_title(fig, title):
-    """ matplotlib suddenly deprecated fig.canvas.set_window_title.
-    """
+    """matplotlib suddenly deprecated fig.canvas.set_window_title."""
     fig.canvas.manager.set_window_title(title)
 
+
 def get_figure_title(fig):
-    """ matplotlib suddenly deprecated fig.canvas.get_window_title.
-    """
+    """matplotlib suddenly deprecated fig.canvas.get_window_title."""
     return fig.canvas.manager.get_window_title()
-
-
